@@ -15,25 +15,40 @@
 #    junto a este programa. 
 #    En caso contrario, consulte <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------
-fTemp<-function(SolI,BD){
-		SolTemp<-merge(BD,SolI,sort=FALSE)
-		  #Genera secuencia de temperatura a partir de Maxima y Minima de base de datos
-		  result<-within(SolTemp,{
-				Tm=(TempMin+TempMax)/2;
-				Tr=(TempMax-TempMin)/2;
+fTemp<-function(sol, BD){
+  ##sol es un objeto con class='Sol'
+  ##BD es un objecto con class='Meteo', cuyo slot 'data' contiene dos columnas llamadas "TempMax" y "TempMin"
 
-				wp=pi/4
+  stopifnot(class(sol)=='Sol')
+  stopifnot(class(BD)=='Meteo')
+  stopifnot(identical(indexD(sol), indexD(BD)))
 
-				a1=pi*12*(ws-w)/(21*pi+12*ws)
-				a2=pi*(3*pi-12*w)/(3*pi-12*ws)
-				a3=pi*(24*pi+12*(ws-w))/(21*pi+12*ws)
+  indSol<-indexI(sol)	
+  ind.rep<-indexRep(sol)
+  	
+  TempMax=coredata(BD@data$TempMax)[ind.rep]
+  TempMin=coredata(BD@data$TempMin)[ind.rep]
+  ws=coredata(sol@solD$ws)[ind.rep]
+  w=coredata(sol@solI$w)
 
-				T1=Tm-Tr*cos(a1)
-				T2=Tm+Tr*cos(a2)
-				T3=Tm-Tr*cos(a3)
+###Genera secuencia de temperatura a partir de Maxima y Minima de base de datos
 
-				Ta=T1*(w<=ws)+T2*(w>ws&w<=wp)+T3*(w>wp)
-				rm(a1,a2,a3,T1,T2,T3,Tm,Tr,wp)
-				Ta})
-				}
+  Tm=(TempMin+TempMax)/2;
+  Tr=(TempMax-TempMin)/2;
+
+  wp=pi/4
+
+  a1=pi*12*(ws-w)/(21*pi+12*ws)
+  a2=pi*(3*pi-12*w)/(3*pi-12*ws)
+  a3=pi*(24*pi+12*(ws-w))/(21*pi+12*ws)
+
+  T1=Tm-Tr*cos(a1)
+  T2=Tm+Tr*cos(a2)
+  T3=Tm-Tr*cos(a3)
+
+  Ta=T1*(w<=ws)+T2*(w>ws&w<=wp)+T3*(w>wp)
+
+###Resultado
+  result<-zoo(Ta, indSol)
+}
 			
